pub struct FileOptions(/* private fields */);Expand description
Per-file analysis options input.
This is a separate #[salsa::input] from [SourceFile] so that changing
options for one file does not touch the source revision of any other file.
The options_digest derived query reads only this struct.
Implementations
Sourceimpl FileOptions
impl FileOptions
pub fn ingredient(db: &dyn Database) -> &IngredientImpl<Self>
pub fn ingredient_mut( zalsa_mut: &mut Zalsa, ) -> (&mut IngredientImpl<Self>, &mut Runtime)
Sourceimpl FileOptions
impl FileOptions
pub fn new<Db_>(db: &Db_, options: AnalysisOptions) -> Self
pub fn builder(options: AnalysisOptions) -> <Self as HasBuilder>::Builder
Sourcepub fn options<'db, Db_>(self, db: &'db Db_) -> AnalysisOptions
pub fn options<'db, Db_>(self, db: &'db Db_) -> AnalysisOptions
Full analysis options for this file.
pub fn set_options<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = AnalysisOptions> + use<'db, Db_>
Sourcepub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Resultwhere
for<'__trivial_bounds> AnalysisOptions: Debug,
pub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Resultwhere
for<'__trivial_bounds> AnalysisOptions: Debug,
Default debug formatting for this struct (may be useful if you define your own Debug impl)