pub struct WorkspaceInputs(/* private fields */);Expand description
Workspace-scoped schema input (spec 11.4).
There is exactly one WorkspaceInputs per database. The schema is
shared across all files; changing it invalidates all schema-dependent
derived queries regardless of which file they belong to.
schema is None when no schema is configured (schema-free mode, 7.1).
Implementations
Sourceimpl WorkspaceInputs
impl WorkspaceInputs
pub fn ingredient(db: &dyn Database) -> &IngredientImpl<Self>
pub fn ingredient_mut( zalsa_mut: &mut Zalsa, ) -> (&mut IngredientImpl<Self>, &mut Runtime)
Sourceimpl WorkspaceInputs
impl WorkspaceInputs
pub fn new<Db_>(db: &Db_, schema: Option<Arc<dyn SchemaProvider>>) -> Self
pub fn builder( schema: Option<Arc<dyn SchemaProvider>>, ) -> <Self as HasBuilder>::Builder
Sourcepub fn schema<'db, Db_>(self, db: &'db Db_) -> Option<Arc<dyn SchemaProvider>>
pub fn schema<'db, Db_>(self, db: &'db Db_) -> Option<Arc<dyn SchemaProvider>>
Workspace-scoped schema. None = schema-free analysis.
pub fn set_schema<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = Option<Arc<dyn SchemaProvider>>> + use<'db, Db_>
Sourcepub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
pub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
Default debug formatting for this struct (may be useful if you define your own Debug impl)